15.96. cdist-type__package_pip(7) — cdist 4.10.4 documentation

# 15.96. cdist-type__package_pip(7)

## 15.96.1. NAME

cdist-type__package_pip - Manage packages with pip

## 15.96.2. DESCRIPTION

Pip is used in Python environments to install packages. It is also included in the python virtualenv environment.

## 15.96.3. REQUIRED PARAMETERS

None

## 15.96.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
pip
  Instead of using pip from PATH, use the specific pip path.
state
  Either "present" or "absent", defaults to "present"
runas
  Run pip as specified user. By default it runs as root.

## 15.96.5. EXAMPLES

    # Install a package
    __package_pip pyro --state present

    # Use pip in a virtualenv located at /root/shinken_virtualenv
    __package_pip pyro --state present --pip /root/shinken_virtualenv/bin/pip

    # Use pip in a virtualenv located at /foo/shinken_virtualenv as user foo
    __package_pip pyro --state present --pip /foo/shinken_virtualenv/bin/pip --runas foo

## 15.96.6. SEE ALSO

cdist-type__package(7)

## 15.96.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 15.96.8. COPYING

Copyright (C) 2012 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.